/* gsm-session-manager.h - functions for monitoring the session
 *
 * Copyright (C) 2008 Red Hat, Inc
 * Author: Matthias Clasen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  
 */
#ifndef GSM_SESSION_MANAGER_H
#define GSM_SESSION_MANAGER_H

#include <glib-object.h>

G_BEGIN_DECLS

#define GSM_TYPE_SESSION_MANAGER		(gsm_session_manager_get_type ())
#define GSM_SESSION_MANAGER(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), GSM_TYPE_SESSION_MANAGER, GsmSessionManager))
#define GSM_SESSION_MANAGER_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), GSM_TYPE_SESSION_MANAGER, GsmSessionManagerClass))
#define GSM_IS_SESSION_MANAGER(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GSM_TYPE_SESSION_MANAGER))
#define GSM_IS_SESSION_MANAGER_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GSM_TYPE_SESSION_MANAGER))
#define GSM_SESSION_MANAGER_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), GSM_TYPE_SESSION_MANAGER, GsmSessionManagerClass))

typedef struct _GsmSessionManager		GsmSessionManager;
typedef struct _GsmSessionManagerClass		GsmSessionManagerClass;
typedef struct _GsmSessionManagerPrivate	GsmSessionManagerPrivate;

struct _GsmSessionManager {
	GObject parent_instance;

	GsmSessionManagerPrivate *priv;
};

struct _GsmSessionManagerClass {
	GObjectClass parent_class;

	/* signals */
	void (* client_added) (GsmSessionManager *manager, 
			       const char        *obj_path);
	void (*client_removed) (GsmSessionManager *manager,
				const char        *obj_path);
};

typedef void (*GsmClientDetailsCallback) (const char *obj_path,
                                          guint       pid,
                                          guint       status,
                                          guint       restart_style_hint,
                                          gpointer    data);

GType gsm_session_manager_get_type (void);

GsmSessionManager *gsm_session_manager_new (void) G_GNUC_MALLOC;
GsmSessionManager *gsm_session_manager_get (void);
void               gsm_session_manager_foreach (GsmSessionManager        *manager,
                                                GsmClientDetailsCallback  callbac,
                                                gpointer                  data);
gboolean	   gsm_session_manager_get_details (GsmSessionManager    *manager,
						    const char           *obj_path,
						    guint                *pid,
						    guint		 *status,
						    guint		 *restart_style);

G_END_DECLS

#endif /* GSM_SESSION_MANAGER_H */
